@@ -1,13 +1,13 @@
 <?php
 /**
-* Locale functions
+* Locale class
 *
 * @package Phamm
 */
 
 /*
 * Phamm - http://www.phamm.org - <team@phamm.org>
-* Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
+* Copyright (C) 2004,2014 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
 *  
@@ -26,24 +26,37 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-
-/**
-* Set right locales from config, user input, auto...
-*
-* @todo
-* @author Alessandro De Zorzi <adezorzi AT rhx DOT it>
-*
-* @return string
-**/
-
-function locale_set($language)
+class PhammLocale
 {
-    global $supported_languages;
+    private $language;
 
-    if (array_key_exists($language,$supported_languages))
-	return $language;
-    else
-	return 'en_GB';
+    function __construct()
+    {
+	if (!isset($_SESSION["language"]))
+	    $this->language = DEFAULT_LANGUAGE;
+	else
+	    $this->language = $_SESSION["language"];
+    }
+
+    public function change_language($new_language)
+    {
+	global $supported_languages;
+
+	if (array_key_exists($new_language, $supported_languages))
+	{
+	    $this->language = $new_language;
+	    $_SESSION["language"] = $new_language;
+	    return true;
+	}
+	else
+	{
+	    return false;
+	}
+    }
+
+    public function get_language()
+    {
+	return $this->language;
+    }
+//
 }
-
-?>
